@@ -46,6 +46,8 @@ class SystemTestCase(base.TestCase):
         self.sys_inst = system.System(
             self.conn, '/redfish/v1/Systems/437XR1138R2',
             redfish_version='1.0.2')
+        self.sys_inst._get_etag = mock.Mock()
+        self.sys_inst._get_etag.return_value = '81802dbf61beb0bd'
 
     def test__parse_attributes(self):
         self.sys_inst._parse_attributes(self.json_doc)
@@ -283,7 +285,7 @@ class SystemTestCase(base.TestCase):
             data={'Boot': {'BootSourceOverrideEnabled': 'Continuous',
                            'BootSourceOverrideTarget': 'Pxe',
                            'BootSourceOverrideMode': 'UEFI'}},
-            headers=None)
+            etag='81802dbf61beb0bd')
 
     def test_set_system_boot_options_no_mode_specified(self):
         self.sys_inst.set_system_boot_options(
@@ -293,7 +295,7 @@ class SystemTestCase(base.TestCase):
             '/redfish/v1/Systems/437XR1138R2',
             data={'Boot': {'BootSourceOverrideEnabled': 'Once',
                            'BootSourceOverrideTarget': 'Hdd'}},
-            headers=None)
+            etag='81802dbf61beb0bd')
 
     def test_set_system_boot_options_no_target_specified(self):
         self.sys_inst.set_system_boot_options(
@@ -303,7 +305,7 @@ class SystemTestCase(base.TestCase):
             '/redfish/v1/Systems/437XR1138R2',
             data={'Boot': {'BootSourceOverrideEnabled': 'Continuous',
                            'BootSourceOverrideMode': 'UEFI'}},
-            headers=None)
+            etag='81802dbf61beb0bd')
 
     def test_set_system_boot_options_no_freq_specified(self):
         self.sys_inst.set_system_boot_options(
@@ -313,13 +315,11 @@ class SystemTestCase(base.TestCase):
             '/redfish/v1/Systems/437XR1138R2',
             data={'Boot': {'BootSourceOverrideTarget': 'Pxe',
                            'BootSourceOverrideMode': 'UEFI'}},
-            headers=None)
+            etag='81802dbf61beb0bd')
 
     def test_set_system_boot_options_nothing_specified(self):
         self.sys_inst.set_system_boot_options()
-        self.sys_inst._conn.patch.assert_called_once_with(
-            '/redfish/v1/Systems/437XR1138R2', data={},
-            headers=None)
+        self.sys_inst._conn.patch.assert_not_called()
 
     def test_set_system_boot_options_invalid_target(self):
         self.assertRaises(exceptions.InvalidParameterValueError,
@@ -350,7 +350,7 @@ class SystemTestCase(base.TestCase):
             '/redfish/v1/Systems/437XR1138R2',
             data={'Boot': {'BootSourceOverrideEnabled': 'Once',
                            'BootSourceOverrideTarget': 'UsbCd'}},
-            headers=None)
+            etag='81802dbf61beb0bd')
 
     def test_set_system_boot_options_supermicro_no_usb_cd_boot(self):
 
@@ -363,16 +363,24 @@ class SystemTestCase(base.TestCase):
             '/redfish/v1/Systems/437XR1138R2',
             data={'Boot': {'BootSourceOverrideEnabled': 'Once',
                            'BootSourceOverrideTarget': 'Cd'}},
-            headers=None)
+            etag='81802dbf61beb0bd')
 
     def test_set_system_boot_options_settings_resource_nokia(self):
-        self.conn.get.return_value.headers = {'ETag': '"3d7b838291941d"'}
         with open('sushy/tests/unit/json_samples/settings-nokia.json') as f:
             settings_obj = json.load(f)
 
         self.json_doc.update(settings_obj)
         self.sys_inst._parse_attributes(self.json_doc)
 
+        with open('sushy/tests/unit/json_samples/'
+                  'settings-body-nokia.json') as f:
+            settings_body = json.load(f)
+
+        get_settings = mock.MagicMock(headers={'ETag': '"3d7b838291941d"'})
+        get_settings.json.return_value = settings_body
+        get_system = mock.MagicMock(headers={'ETag': '"222"'})
+        self.conn.get.side_effect = [get_settings, get_system]
+
         self.sys_inst.set_system_boot_options(
             target=sushy.BootSource.CD,
             enabled=sushy.BootSourceOverrideEnabled.ONCE)
@@ -381,16 +389,26 @@ class SystemTestCase(base.TestCase):
             '/redfish/v1/Systems/Self/SD',
             data={'Boot': {'BootSourceOverrideEnabled': 'Once',
                            'BootSourceOverrideTarget': 'Cd'}},
-            headers={'If-Match': '"3d7b838291941d"'})
+            etag='"3d7b838291941d"')
 
     def test_set_system_boot_options_settings_resource(self):
-        self.conn.get.return_value.headers = {'ETag': '"3d7b838291941d"'}
         with open('sushy/tests/unit/json_samples/settings.json') as f:
             settings_obj = json.load(f)
 
         self.json_doc.update(settings_obj)
         self.sys_inst._parse_attributes(self.json_doc)
 
+        with open('sushy/tests/unit/json_samples/'
+                  'settings-body-nokia.json') as f:
+            settings_body = json.load(f)
+
+        get_settings = mock.MagicMock(headers={'ETag': '"3d7b838291941d"'})
+        get_settings.json.return_value = settings_body
+        get_system = mock.MagicMock(headers={'ETag': '"222"'})
+        self.conn.get.side_effect = [get_settings, get_system]
+
+        self.conn.get.return_value.json.return_value = settings_body
+
         self.sys_inst.set_system_boot_options(
             target=sushy.BootSource.CD,
             enabled=sushy.BootSourceOverrideEnabled.ONCE)
@@ -399,7 +417,67 @@ class SystemTestCase(base.TestCase):
             '/redfish/v1/Systems/437XR1138R2/BIOS/Settings',
             data={'Boot': {'BootSourceOverrideEnabled': 'Once',
                            'BootSourceOverrideTarget': 'Cd'}},
-            headers={'If-Match': '"3d7b838291941d"'})
+            etag='"3d7b838291941d"')
+
+    def test_set_system_boot_options_settings_resource_lenovo(self):
+        self.sys_inst = system.System(
+            self.conn, '/redfish/v1/Systems/1',
+            redfish_version='1.0.2')
+
+        with open('sushy/tests/unit/json_samples/'
+                  'settings-lenovo-se450.json') as f:
+            settings_obj = json.load(f)
+
+        self.json_doc.update(settings_obj)
+        self.sys_inst._parse_attributes(self.json_doc)
+
+        with open('sushy/tests/unit/json_samples/'
+                  'settings-body-lenovo-se450.json') as f:
+            settings_body = json.load(f)
+
+        get_settings = mock.MagicMock(headers={'ETag': '"3d7b838291941d"'})
+        get_settings.json.return_value = settings_body
+        get_system = mock.MagicMock(headers={'ETag': '"222"'})
+        self.conn.get.side_effect = [get_settings, get_system]
+
+        self.sys_inst.set_system_boot_options(
+            target=sushy.BootSource.CD,
+            enabled=sushy.BootSourceOverrideEnabled.ONCE)
+
+        self.sys_inst._conn.patch.assert_called_once_with(
+            '/redfish/v1/Systems/1',
+            data={'Boot': {'BootSourceOverrideEnabled': 'Once',
+                           'BootSourceOverrideTarget': 'Cd'}},
+            etag='"222"')
+
+    def test_set_system_boot_options_settings_resource_bootmode_only(self):
+        self.sys_inst = system.System(
+            self.conn, '/redfish/v1/Systems/1',
+            redfish_version='1.0.2')
+
+        with open('sushy/tests/unit/json_samples/'
+                  'settings-nokia.json') as f:
+            settings_obj = json.load(f)
+
+        self.json_doc.update(settings_obj)
+        self.sys_inst._parse_attributes(self.json_doc)
+
+        with open('sushy/tests/unit/json_samples/'
+                  'settings-body-bootsourceoverridemode-only.json') as f:
+            settings_body = json.load(f)
+
+        get_settings = mock.MagicMock(headers={'ETag': '"3d7b838291941d"'})
+        get_settings.json.return_value = settings_body
+        get_system = mock.MagicMock(headers={'ETag': '"222"'})
+        self.conn.get.side_effect = [get_settings, get_system]
+
+        self.sys_inst.set_system_boot_options(
+            mode=sushy.BootSourceOverrideMode.UEFI)
+
+        self.sys_inst._conn.patch.assert_called_with(
+            '/redfish/v1/Systems/Self/SD',
+            data={'Boot': {'BootSourceOverrideMode': 'UEFI'}},
+            etag='"3d7b838291941d"')
 
     def test_set_system_boot_source(self):
         self.sys_inst.set_system_boot_source(
@@ -411,10 +489,10 @@ class SystemTestCase(base.TestCase):
             data={'Boot': {'BootSourceOverrideEnabled': 'Continuous',
                            'BootSourceOverrideTarget': 'Pxe',
                            'BootSourceOverrideMode': 'UEFI'}},
-            headers=None)
+            etag='81802dbf61beb0bd')
 
     def test_set_system_boot_source_with_etag(self):
-        self.conn.get.return_value.headers = {'ETag': '"3d7b838291941d"'}
+        self.conn.get.return_value.headers = {'ETag': '"81802dbf61beb0bd"'}
         self.sys_inst.set_system_boot_source(
             sushy.BOOT_SOURCE_TARGET_PXE,
             enabled=sushy.BOOT_SOURCE_ENABLED_CONTINUOUS,
@@ -424,7 +502,7 @@ class SystemTestCase(base.TestCase):
             data={'Boot': {'BootSourceOverrideEnabled': 'Continuous',
                            'BootSourceOverrideTarget': 'Pxe',
                            'BootSourceOverrideMode': 'UEFI'}},
-            headers={'If-Match': '"3d7b838291941d"'})
+            etag="81802dbf61beb0bd")
 
     def test_set_system_boot_source_no_mode_specified(self):
         self.sys_inst.set_system_boot_source(
@@ -434,7 +512,7 @@ class SystemTestCase(base.TestCase):
             '/redfish/v1/Systems/437XR1138R2',
             data={'Boot': {'BootSourceOverrideEnabled': 'Once',
                            'BootSourceOverrideTarget': 'Hdd'}},
-            headers=None)
+            etag='81802dbf61beb0bd')
 
     def test_set_system_boot_source_invalid_target(self):
         self.assertRaises(exceptions.InvalidParameterValueError,
@@ -457,7 +535,8 @@ class SystemTestCase(base.TestCase):
             self.sys_inst.set_indicator_led(sushy.IndicatorLED.BLINKING)
             self.sys_inst._conn.patch.assert_called_once_with(
                 '/redfish/v1/Systems/437XR1138R2',
-                data={'IndicatorLED': 'Blinking'})
+                data={'IndicatorLED': 'Blinking'},
+                etag='81802dbf61beb0bd')
 
             invalidate_mock.assert_called_once_with()
 
